import com.phidgets.*;
import com.phidgets.event.*;
import java.io.*;

public class DataLogger {

    public static final void main(String args[]) throws Exception {

        // Clear and open the csv file for writing, and write the header
        final FileOutputStream outFile = new FileOutputStream("temperature_data_java.csv");
        String header = "Time,Thermocouple-Temperature,Ambient-Board-Temperature\n";
        outFile.write(header.getBytes(), 0, header.length());
        outFile.flush();

        // Get a start time from which we can generate timestamps later
        final long start = System.nanoTime();

        // Create the Phidget software object
        TemperatureSensorPhidget device;
        device = new TemperatureSensorPhidget();

        // Attach a listener function to changes in thermocouple temperature
        TemperatureChangeListener temperatureDataHandler;
        device.addTemperatureChangeListener(new TemperatureChangeListener() {
            public void temperatureChanged(TemperatureChangeEvent event) {

                long now = System.nanoTime();
                // The nanoTime() function gives us microseconds; we want seconds.
                double timeDifference = (now - start) / 1000000000.0;
                // Initialize the board temperature with some impossible number
                double ambientTemperature = -99;   

                // Cast the event into a specific (TemperatureSensor) Phidget
                // This must be done separately from calling a device function
                TemperatureSensorPhidget localDevice = (TemperatureSensorPhidget)event.getSource();

                // Get the board temperature
                try {
                    ambientTemperature = localDevice.getAmbientTemperature();
                } catch (PhidgetException exception) {
                    System.out.println(exception);
                }

                // Print dots to indiciate one more point recorded
                System.out.print(".");
                System.out.flush();
    
                // Write the data to the text file
                String output = timeDifference + "," + event.getValue() + "," + ambientTemperature + "\n";
                try {
                    outFile.write(output.getBytes(), 0, output.length());
                    outFile.flush();
                } catch (IOException exception) {
                    System.out.println(exception);
                }

            }
        });

        // Open the device and make sure it is plugged in
        device.openAny();
        device.waitForAttachment(10000);

        // Set the thermocouple type and trigger (0 = record all data)
        try {
            device.setThermocoupleType(0, device.PHIDGET_TEMPERATURE_SENSOR_K_TYPE);
            device.setTemperatureChangeTrigger(0, 0);
        } catch (PhidgetException exception) {
            System.out.println(exception);
        }
        
        System.out.println("Press Enter to end anytime...\n");
        System.in.read();

        outFile.close();

        device.close();
        device = null;
    }
}

//==============================================================================
// EOF
//==============================================================================

